@@ -15,12 +15,14 @@ PATH_TYPES = {
 
 #: Maps Flask-Restful/plus fields types to Swagger ones
 FIELDS = {
+    fields.Raw: {'type': 'string'},
     fields.String: {'type': 'string'},
     fields.Integer: {'type': 'integer'},
     fields.Boolean: {'type': 'boolean'},
     fields.Float: {'type': 'number'},
     fields.Arbitrary: {'type': 'number'},
     fields.DateTime: {'type': 'string', 'format': 'date-time'},
+    fields.Fixed: {'type': 'number'},
 }
 
 
@@ -29,6 +31,8 @@ LOCATIONS = {
     'args': 'query',
     'form': 'form',
     'headers': 'header',
+    'json': 'body',
+    'values': 'query',
 }
 
 
